==> drop_account-2.3.1.tar.gz: drop_account/l10n/cs.js <==
OC.L10N.register(
    "drop_account",
    {
    "%1$s (%2$s - %3$s) deleted their account" : "%1$s (%2$s - %3$s) smazal(a) svůj účet",
    "%1$s (%2$s) deleted their account" : "%1$s (%2$s) smazal(a) svůj účet",
    "%1$s deleted their account" : "%1$s smazal(a) svůj účet",
    "An user <strong>deleted</strong> its account" : "Uživatel <strong>smazal</strong> svůj účet",
    "User-Session unexpectedly expired" : "Platnost uživatelské relace neočekávaně skončila",
    "Successfully sent email" : "E-mail úspěšně odeslán",
    "You have no email set up into your account" : "Ve svém účtu nemáte nastavenou žádnou e-mailovou adresu",
    "Unexpected error sending email. Please contact your administrator." : "Neočekávaná chyba při odesílání e-mailu. Obraťte se na správce.",
    "Confirm your account deletion on %s" : "Potvrďte smazání svého účtu na %s",
    "Account deletion confirmation for %s" : "Potvrzení smazání účtu pro %s",
    "Hello," : "Dobrý den,",
    "Someone - probably you - asked to delete their account on %s." : "Někdo – nejspíš Vy – požádal(a) o smazání svého účtu na %s.",
    "To confirm the account deletion, you may click on the button below." : "Pokud chcete potvrdit smazání účtu, klikněte na níže uvedené tlačítko.",
    "If you didn't request this email, you should contact your administrator as soon as possible, someone may be accessing your account without your knowledge." : "Pokud jste tento e-mail nevyžádali, měli byste se obrátit co nejdříve na správce, protože někdo jiný možná přistupuje k vašemu účtu bez vašeho vědomí.",
    "Delete account" : "Smazat účet",
    "Cheers!" : "Nazdar!",
    "Your account on %s has been disabled" : "Váš účet na %s byl deaktivován",
    "Your account on %s has been deleted" : "Váš účet na %s byl smazán",
    "Account deletion on %s scheduled" : "Naplánováno smazání účtu na %s",
    "Account on %s deleted" : "Účet na %s smazán",
    "Hi," : "Ahoj,",
    "_Your data will be permanently deleted in %d hour._::_Your data will be permanently deleted in %d hours._" : ["Vaše data budou nevratně smazána za %d hodinu.","Vaše data budou nevratně smazána za %d hodiny.","-Vaše data budou nevratně smazána za %d hodin."],
    "_Your data will be permanently deleted in %d day, on %s._::_Your data will be permanently deleted in %d days, on %s._" : ["Vaše data budou nevratně smazána za %d den, v %s.","Vaše data budou nevratně smazána za %d dny, v %s.","Vaše data budou nevratně smazána za %d dnů, v %s."],
    "You can cancel your account deletion by contacting an administrator before the %s." : "Smazání účtu je možné zrušit kontaktováním správce před %s.",
    "We confirm all your personal data on %s was permanently deleted." : "Potvrzujeme, že veškerá vaše osobní data na %s byly nenávratně smazány.",
    "Thanks for using our service." : "Děkujeme za použití naší služby.",
    "Your account on %s has been reactivated" : "Váš účet na %s byl znovu zprovozněn",
    "Access to your account %1$s has been restored" : "Přístup k vašemu účtu na %1$s byl obnoven",
    "An administrator re-enabled your account on %s before it was destroyed." : "Správce znovu zprovoznil váš účet na %s ještě před jeho zničením.",
    "Your account is available again, none of your data was removed. You may now login again." : "Váš účet je znovu k dispozici, žádná vaše data nebyla odebrána. Nyní se můžete opět přihlásit.",
    "Login" : "Přihlášení",
    "User account deletion" : "Smazání uživatelského účtu",
    "An app to allow users to delete their accounts." : "Aplikace umožňující uživatelům smazat si své účty.",
    "# Description\n\nThis app allows users to delete their accounts by removing all their data.\n\nIt can also send activities to the admins about deleted accounts." : "# Popis\n\nTato aplikace uživatelům umožňuje smazat si své účty odebráním veškerých jejich dat.\n\nTaké může posílat aktivity správcům ohledně smazaných účtů.",
    "Account deletion" : "Mazání účtu",
    "Allows users to delete themselves their own account." : "Umožňuje uživatelům smazat si svůj vlastní účet.",
    "Email confirmation" : "Potvrzení e-mailem",
    "Require confirmation by email" : "Vyžadovat potvrzení e-mailem",
    "Will require users to click a confirmation link sent by email to confirm their action." : "Bude od uživatelů vyžadovat kliknout na potvrzovací odkaz poslaný e-mailem a potvrdit tak danou akci.",
    "Data purge" : "Smazání dat",
    "Users are not removed right away but disabled until a background job removed their data for good. In the meanwhile, admins can \"save\" users by enabling them back." : "Uživatelé nejsou hned odebráni ale deaktivováni dokud úloha spouštěná na pozadí nesmaže jejich data nadobro. Mezitím mohou správci „zachránit“ uživatele znovupovolením jejich účtů.",
    "Purge user data as soon as possible." : "Smazat data uživatele co nejdříve.",
    "Uses the next background job available to completely remove the user's data." : "Použije nejbližší úlohu spouštěnou na pozadí pro úplné odebrání dat uživatele.",
    "Purge user data after a while." : "Smaže data uživatele po nějaké době.",
    "Deletes user data after a grace period." : "Smaže data uživatele po uplynutí ochranné doby.",
    "Grace period duration" : "Délka ochranné doby",
    "One day" : "Jeden den",
    "One week" : "Jeden týden",
    "One month" : "Jeden měsíc",
    "Error while changing require confirmation setting" : "Chyba při změně nastavení vyžadovaného potvrzení",
    "Error while changing delay purge setting" : "Chyba při změně nastavení prodlevy smazání",
    "Error while changing delay purge hours setting" : "Chyba při změně nastavení hodin prodlevy smazání",
    "Delete my account" : "Smazat můj účet",
    "Deleting your account will delete all your files and data from the apps you use, such as calendar and contacts." : "Smazání vašeho účtu smaže veškeré vaše soubory a data z aplikací, které používáte, jako je kalendář a kontakty.",
    "Account marked for deletion" : "Účet označen pro smazání",
    "Your account has been disabled and the data will be removed shortly." : "Váš účet byl deaktivován a data budou zakrátko smazána.",
    "You are going to be redirected to the login page in a few seconds…" : "Za několik sekund budete přesměrováni na přihlašovací stránku…",
    "Email confirmation required" : "Vyžadováno potvrzení e-mailem",
    "Please click the link into the email we've just sent you to finish deleting your account." : "Klikněte na odkaz v e-mailu, který jsme vám právě poslali a dokončete tak smazání svého účtu.",
    "This action is irreversible!" : "Tuto akci nelze vzít zpět!",
    "After confirming the deletion of your account, you will be redirected to the login page." : "Po potvrzení smazání vašeho účtu budete přesměrováni na přihlašovací stránku.",
    "You are the only user of this instance, you can't delete your account." : "Jste jediným uživatelem na této instanci, proto svůj účet nemůžete smazat.",
    "You are the only admin of this instance, you can't delete your account." : "Jste jediným správcem na této instanci, proto svůj účet nemůžete smazat.",
    "An email confirmation is required by your admin to delete your account. Please fill your email in your personal settings first." : "Správce stanovil, že smazání vašeho účtu vyžaduje potvrzení prostřednictvím e-mailu. Nejprve vyplňte e-mailovou adresu ve svých osobních nastaveních.",
    "Do you really wish to delete your account?" : "Opravdu chcete svůj účet smazat?",
    "We will send you an email to confirm this action." : "Pošleme vám e-mail ohledně potvrzení této akce.",
    "Check this to confirm the deletion request" : "Pokud chcete potvrdit tento požadavek na smazání, zaškrtněte toto",
    "Deleting your data…" : "Mazání vašich dat…",
    "Error while deleting the account" : "Chyba při mazání účtu",
    "_This action will be reversible by an administrator for {nbDays} day after you request deletion._::_This action will be reversible by an administrator for {nbDays} days after you request deletion._" : ["Tato akce bude nevratná ani správci za {nbDays} den po vaší žádosti o smazání.","Tato akce bude nevratná ani správci za {nbDays} dny po vaší žádosti o smazání.","Tato akce bude nevratná ani správci za {nbDays} dnů po vaší žádosti o smazání."],
    "Your account has been marked for deletion. You can now close this window." : "Váš účet byl označen pro smazání. Toto okno nyní můžete zavřít.",
    "Account not found." : "Účet nenalezen.",
    "The token provided was not found." : "Zadaný token nenalezen.",
    "Make sure the link opened is valid or that you are logged-in with the correct user." : "Ověřte, že otevíraný odkaz je platný nebo že jste přihlášení jako správný uživatel.",
    "Back to %s" : "Zpět na %s",
    "Unknown error." : "Neznámá chyba."
},
"nplurals=3; plural=(n==1) ? 0 : (n>=2 && n<=4) ? 1 : 2;");

==> drop_account-2.4.0.tar.gz: drop_account/l10n/cs.js <==
OC.L10N.register(
    "drop_account",
    {
    "%1$s (%2$s - %3$s) deleted their account" : "%1$s (%2$s - %3$s) smazal(a) svůj účet",
    "%1$s (%2$s) deleted their account" : "%1$s (%2$s) smazal(a) svůj účet",
    "%1$s deleted their account" : "%1$s smazal(a) svůj účet",
    "%1$s requested to delete their account. It has been disabled and will automatically be removed on %2$s" : "Váš účet byl deaktivován a data budou zakrátko smazána.",
    "Account %1$s has been re-enabled by an admin" : "Váš účet na %s byl deaktivován",
    "A user <strong>deleted</strong> its account" : "Uživatel <strong>smazal</strong> svůj účet",
    "User session not found" : "Účet nenalezen.",
    "User-Session unexpectedly expired" : "Platnost uživatelské relace neočekávaně skončila",
    "Successfully sent email" : "E-mail úspěšně odeslán",
    "You have no email set up into your account" : "Ve svém účtu nemáte nastavenou žádnou e-mailovou adresu",
    "Unexpected error sending email. Please contact your administrator." : "Neočekávaná chyba při odesílání e-mailu. Obraťte se na správce.",
    "Confirm your account deletion on %s" : "Potvrďte smazání svého účtu na %s",
    "Account deletion confirmation for %s" : "Potvrzení smazání účtu pro %s",
    "Hello," : "Dobrý den,",
    "Someone - probably you - asked to delete their account on %s." : "Někdo – nejspíš Vy – požádal(a) o smazání svého účtu na %s.",
    "To confirm the account deletion, you may click on the button below." : "Pokud chcete potvrdit smazání účtu, klikněte na níže uvedené tlačítko.",
    "If you didn't request this email, you should contact your administrator as soon as possible, someone may be accessing your account without your knowledge." : "Pokud jste tento e-mail nevyžádali, měli byste se obrátit co nejdříve na správce, protože někdo jiný možná přistupuje k vašemu účtu bez vašeho vědomí.",
    "Delete account" : "Smazat účet",
    "Cheers!" : "Nazdar!",
    "You are the only user on the server, you can't delete your account." : "Jste jediným uživatelem na této instanci, proto svůj účet nemůžete smazat.",
    "You are the only admin on the server, you can't delete your account." : "Jste jediným správcem na této instanci, proto svůj účet nemůžete smazat.",
    "Your account on %s has been disabled" : "Váš účet na %s byl deaktivován",
    "Your account on %s has been deleted" : "Váš účet na %s byl smazán",
    "Account deletion on %s scheduled" : "Naplánováno smazání účtu na %s",
    "Account on %s deleted" : "Účet na %s smazán",
    "Hi," : "Ahoj,",
    "_Your data will be permanently deleted in %n hour._::_Your data will be permanently deleted in %n hours._" : ["Vaše data budou nevratně smazána za %d hodinu.","Vaše data budou nevratně smazána za %d hodiny.","-Vaše data budou nevratně smazána za %d hodin."],
    "_Your data will be permanently deleted in %n day, on %s._::_Your data will be permanently deleted in %n days, on %s._" : ["Vaše data budou nevratně smazána za %d den, v %s.","Vaše data budou nevratně smazána za %d dny, v %s.","Vaše data budou nevratně smazána za %d dnů, v %s."],
    "You can cancel your account deletion by contacting an administrator before the %s." : "Smazání účtu je možné zrušit kontaktováním správce před %s.",
    "We confirm all your personal data on %s was permanently deleted." : "Potvrzujeme, že veškerá vaše osobní data na %s byly nenávratně smazány.",
    "Thanks for using our service." : "Děkujeme za použití naší služby.",
    "Your account on %s has been reactivated" : "Váš účet na %s byl znovu zprovozněn",
    "Access to your account %1$s has been restored" : "Přístup k vašemu účtu na %1$s byl obnoven",
    "An administrator re-enabled your account on %s before it was destroyed." : "Správce znovu zprovoznil váš účet na %s ještě před jeho zničením.",
    "Your account is available again, none of your data was removed. You may now login again." : "Váš účet je znovu k dispozici, žádná vaše data nebyla odebrána. Nyní se můžete opět přihlásit.",
    "Login" : "Přihlášení",
    "User account deletion" : "Smazání uživatelského účtu",
    "An app to allow users to delete their accounts." : "Aplikace umožňující uživatelům smazat si své účty.",
    "# Description\n\nThis app allows users to delete their accounts by removing all their data.\n\nIt can also send activities to the admins about deleted accounts." : "# Popis\n\nTato aplikace uživatelům umožňuje smazat si své účty odebráním veškerých jejich dat.\n\nTaké může posílat aktivity správcům ohledně smazaných účtů.",
    "Account deletion" : "Mazání účtu",
    "Allows users to delete themselves their own account." : "Umožňuje uživatelům smazat si svůj vlastní účet.",
    "Email confirmation" : "Potvrzení e-mailem",
    "Require confirmation by email" : "Vyžadovat potvrzení e-mailem",
    "Will require users to click a confirmation link sent by email to confirm their action." : "Bude od uživatelů vyžadovat kliknout na potvrzovací odkaz poslaný e-mailem a potvrdit tak danou akci.",
    "Data purge" : "Smazání dat",
    "Users are not removed right away but disabled until a background job removes their data for good. In the meanwhile, admins can \"save\" users by enabling them back." : "Uživatelé nejsou hned odebráni ale deaktivováni dokud úloha spouštěná na pozadí nesmaže jejich data nadobro. Mezitím mohou správci „zachránit“ uživatele znovupovolením jejich účtů.",
    "Purge user data as soon as possible." : "Smazat data uživatele co nejdříve.",
    "Uses the next background job available to completely remove the user's data." : "Použije nejbližší úlohu spouštěnou na pozadí pro úplné odebrání dat uživatele.",
    "Purge user data after a while." : "Smaže data uživatele po nějaké době.",
    "Deletes user data after a grace period." : "Smaže data uživatele po uplynutí ochranné doby.",
    "Grace period duration" : "Délka ochranné doby",
    "One day" : "Jeden den",
    "One week" : "Jeden týden",
    "One month" : "Jeden měsíc",
    "Error while changing require confirmation setting" : "Chyba při změně nastavení vyžadovaného potvrzení",
    "Error while changing delay purge setting" : "Chyba při změně nastavení prodlevy smazání",
    "Error while changing delay purge hours setting" : "Chyba při změně nastavení hodin prodlevy smazání",
    "Delete my account" : "Smazat můj účet",
    "Deleting your account will delete all your files and data from the apps you use, such as calendar and contacts." : "Smazání vašeho účtu smaže veškeré vaše soubory a data z aplikací, které používáte, jako je kalendář a kontakty.",
    "Account marked for deletion" : "Účet označen pro smazání",
    "Your account has been disabled and the data will be removed shortly." : "Váš účet byl deaktivován a data budou zakrátko smazána.",
    "You are going to be redirected to the login page in a few seconds…" : "Za několik sekund budete přesměrováni na přihlašovací stránku…",
    "Email confirmation required" : "Vyžadováno potvrzení e-mailem",
    "Please click the link into the email we've just sent you to finish deleting your account." : "Klikněte na odkaz v e-mailu, který jsme vám právě poslali a dokončete tak smazání svého účtu.",
    "This action is irreversible!" : "Tuto akci nelze vzít zpět!",
    "After confirming the deletion of your account, you will be redirected to the login page." : "Po potvrzení smazání vašeho účtu budete přesměrováni na přihlašovací stránku.",
    "You are the only user of this instance, you can't delete your account." : "Jste jediným uživatelem na této instanci, proto svůj účet nemůžete smazat.",
    "You are the only admin of this instance, you can't delete your account." : "Jste jediným správcem na této instanci, proto svůj účet nemůžete smazat.",
    "An email confirmation is required by your admin to delete your account. Please fill your email in your personal settings first." : "Správce stanovil, že smazání vašeho účtu vyžaduje potvrzení prostřednictvím e-mailu. Nejprve vyplňte e-mailovou adresu ve svých osobních nastaveních.",
    "Do you really wish to delete your account?" : "Opravdu chcete svůj účet smazat?",
    "We will send you an email to confirm this action." : "Pošleme vám e-mail ohledně potvrzení této akce.",
    "Check this to confirm the deletion request" : "Pokud chcete potvrdit tento požadavek na smazání, zaškrtněte toto",
    "Error while deleting the account" : "Chyba při mazání účtu",
    "_This action will be reversible by an administrator for {nbDays} day after you request deletion._::_This action will be reversible by an administrator for {nbDays} days after you request deletion._" : ["Tato akce bude nevratná ani správci za {nbDays} den po vaší žádosti o smazání.","Tato akce bude nevratná ani správci za {nbDays} dny po vaší žádosti o smazání.","Tato akce bude nevratná ani správci za {nbDays} dnů po vaší žádosti o smazání."],
    "Your account has been marked for deletion. You can now close this window." : "Váš účet byl označen pro smazání. Toto okno nyní můžete zavřít.",
    "Account not found." : "Účet nenalezen.",
    "The token provided was not found." : "Zadaný token nenalezen.",
    "Make sure the link opened is valid or that you are logged-in with the correct user." : "Ověřte, že otevíraný odkaz je platný nebo že jste přihlášení jako správný uživatel.",
    "Back to %s" : "Zpět na %s",
    "Unknown error." : "Neznámá chyba."
},
"nplurals=3; plural=(n==1) ? 0 : (n>=2 && n<=4) ? 1 : 2;");
